==> huaweicloudsdkdws-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/list_snapshot_statistics_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSnapshotStatisticsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'statistics': 'list[SnapshotsStatistic]'
    }

    attribute_map = {
        'statistics': 'statistics'
    }

    def __init__(self, statistics=None):
        r"""ListSnapshotStatisticsResponse

        The model defined in huaweicloud sdk

        :param statistics: 快照统计信息。
        :type statistics: list[:class:`huaweicloudsdkdws.v2.SnapshotsStatistic`]
        """
        
        super(ListSnapshotStatisticsResponse, self).__init__()

        self._statistics = None
        self.discriminator = None

        if statistics is not None:
            self.statistics = statistics

    @property
    def statistics(self):
        r"""Gets the statistics of this ListSnapshotStatisticsResponse.

        快照统计信息。

        :return: The statistics of this ListSnapshotStatisticsResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.SnapshotsStatistic`]
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        r"""Sets the statistics of this ListSnapshotStatisticsResponse.

        快照统计信息。

        :param statistics: The statistics of this ListSnapshotStatisticsResponse.
        :type statistics: list[:class:`huaweicloudsdkdws.v2.SnapshotsStatistic`]
        """
        self._statistics = statistics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSnapshotStatisticsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdws-3.1.155-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/list_snapshot_statistics_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSnapshotStatisticsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'statistics': 'list[SnapshotsStatistic]'
    }

    attribute_map = {
        'statistics': 'statistics'
    }

    def __init__(self, statistics=None):
        r"""ListSnapshotStatisticsResponse

        The model defined in huaweicloud sdk

        :param statistics: **参数解释**： 快照统计信息。 **取值范围**： 不涉及。
        :type statistics: list[:class:`huaweicloudsdkdws.v2.SnapshotsStatistic`]
        """
        
        super(ListSnapshotStatisticsResponse, self).__init__()

        self._statistics = None
        self.discriminator = None

        if statistics is not None:
            self.statistics = statistics

    @property
    def statistics(self):
        r"""Gets the statistics of this ListSnapshotStatisticsResponse.

        **参数解释**： 快照统计信息。 **取值范围**： 不涉及。

        :return: The statistics of this ListSnapshotStatisticsResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.SnapshotsStatistic`]
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        r"""Sets the statistics of this ListSnapshotStatisticsResponse.

        **参数解释**： 快照统计信息。 **取值范围**： 不涉及。

        :param statistics: The statistics of this ListSnapshotStatisticsResponse.
        :type statistics: list[:class:`huaweicloudsdkdws.v2.SnapshotsStatistic`]
        """
        self._statistics = statistics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSnapshotStatisticsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
